==> jc-1.4.0.tar.gz: javax/swing/plaf/InsetsUIResource.h <==
// public class javax.swing.plaf.InsetsUIResource

// class file dependencies
// @dep_class ec052a1e3584fd11 java_awt_Insets
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 40c2e3d3670e9e8b javax_swing_plaf_InsetsUIResource

// header file dependencies
// @dep_header java_awt_Insets

#include "java/awt/Insets.h"

#ifndef _JC_javax_swing_plaf_InsetsUIResource_H_
#define _JC_javax_swing_plaf_InsetsUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_InsetsUIResource$sub_refs	_jc_javax_swing_plaf_InsetsUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs	_jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$refs	_jc_javax_swing_plaf_InsetsUIResource$refs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$nonrefs	_jc_javax_swing_plaf_InsetsUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$object	_jc_javax_swing_plaf_InsetsUIResource$object;

typedef struct _jc_javax_swing_plaf_InsetsUIResource$fields_struct	_jc_javax_swing_plaf_InsetsUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vmethods	_jc_javax_swing_plaf_InsetsUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vtable	_jc_javax_swing_plaf_InsetsUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vtype	_jc_javax_swing_plaf_InsetsUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_InsetsUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_InsetsUIResource$fields_struct _jc_javax_swing_plaf_InsetsUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_InsetsUIResource$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_plaf_InsetsUIResource$object *, jint, jint, jint, jint);

// Virtual methods structure
struct _jc_javax_swing_plaf_InsetsUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_InsetsUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Insets$vmethods	java_awt_Insets;
	_jc_javax_swing_plaf_InsetsUIResource$vmethods	javax_swing_plaf_InsetsUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_InsetsUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_InsetsUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_InsetsUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_InsetsUIResource$refs {
    _jc_javax_swing_plaf_InsetsUIResource$sub_refs	javax_swing_plaf_InsetsUIResource;
    _jc_java_awt_Insets$sub_refs	java_awt_Insets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_InsetsUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Insets$sub_nonrefs	java_awt_Insets;
    _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs	javax_swing_plaf_InsetsUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_InsetsUIResource$object {
	_jc_javax_swing_plaf_InsetsUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_InsetsUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_InsetsUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_InsetsUIResource$vtype _jc_javax_swing_plaf_InsetsUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_InsetsUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_InsetsUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_InsetsUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/InsetsUIResource.h <==
// public class javax.swing.plaf.InsetsUIResource

// class file dependencies
// @dep_class ec052a1e3584fd11 java_awt_Insets
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 40c2e3d3670e9e8b javax_swing_plaf_InsetsUIResource

// header file dependencies
// @dep_header java_awt_Insets

#include "java/awt/Insets.h"

#ifndef _JC_javax_swing_plaf_InsetsUIResource_H_
#define _JC_javax_swing_plaf_InsetsUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_InsetsUIResource$sub_refs	_jc_javax_swing_plaf_InsetsUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs	_jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$refs	_jc_javax_swing_plaf_InsetsUIResource$refs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$nonrefs	_jc_javax_swing_plaf_InsetsUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_InsetsUIResource$object	_jc_javax_swing_plaf_InsetsUIResource$object;

typedef struct _jc_javax_swing_plaf_InsetsUIResource$fields_struct	_jc_javax_swing_plaf_InsetsUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vmethods	_jc_javax_swing_plaf_InsetsUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vtable	_jc_javax_swing_plaf_InsetsUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_InsetsUIResource$vtype	_jc_javax_swing_plaf_InsetsUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_InsetsUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_InsetsUIResource$fields_struct _jc_javax_swing_plaf_InsetsUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_InsetsUIResource$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_javax_swing_plaf_InsetsUIResource$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_InsetsUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_InsetsUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Insets$vmethods	java_awt_Insets;
	_jc_javax_swing_plaf_InsetsUIResource$vmethods	javax_swing_plaf_InsetsUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_InsetsUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_InsetsUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_InsetsUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_InsetsUIResource$refs {
    _jc_javax_swing_plaf_InsetsUIResource$sub_refs	javax_swing_plaf_InsetsUIResource;
    _jc_java_awt_Insets$sub_refs	java_awt_Insets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_InsetsUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Insets$sub_nonrefs	java_awt_Insets;
    _jc_javax_swing_plaf_InsetsUIResource$sub_nonrefs	javax_swing_plaf_InsetsUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_InsetsUIResource$object {
	_jc_javax_swing_plaf_InsetsUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_InsetsUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_InsetsUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_InsetsUIResource$vtype _jc_javax_swing_plaf_InsetsUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_InsetsUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_InsetsUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_InsetsUIResource_H_ */
